==> livingdoc-maven-plugin-2.5-sources.jar: ch/ifocusit/livingdoc/plugin/publish/confluence/client/RequestFailedException.java <==
/*
 * Living Documentation
 *
 * Copyright (C) 2023 Focus IT
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package ch.ifocusit.livingdoc.plugin.publish.confluence.client;

import org.apache.http.HttpRequest;
import org.apache.http.HttpResponse;

import static ch.ifocusit.livingdoc.plugin.utils.InputStreamUtils.inputStreamAsString;

/**
 * @author Alain Sahli
 * @author Christian Stettler
 * @author Julien Boz
 */
class RequestFailedException extends RuntimeException {

    private static final String SPACE = " ";

    RequestFailedException(HttpRequest request, HttpResponse response) {
        super(response.getStatusLine().getStatusCode() + SPACE
                + response.getStatusLine().getReasonPhrase() + SPACE
                + request.getRequestLine().getMethod() + SPACE
                + request.getRequestLine().getUri() + SPACE
                + failedResponseContent(response)
        );
    }

    private static String failedResponseContent(HttpResponse response) {
        try {
            return inputStreamAsString(response.getEntity().getContent());
        } catch (Exception ignored) {
            return "";
        }
    }

}

==> livingdoc-maven-plugin-2.9-sources.jar: ch/ifocusit/livingdoc/plugin/publish/confluence/client/RequestFailedException.java <==
/*
 * Living Documentation
 *
 * Copyright (C) 2024 Focus IT
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package ch.ifocusit.livingdoc.plugin.publish.confluence.client;

import org.apache.http.HttpRequest;
import org.apache.http.HttpResponse;

import static ch.ifocusit.livingdoc.plugin.utils.InputStreamUtils.inputStreamAsString;

/**
 * @author Alain Sahli
 * @author Christian Stettler
 * @author Julien Boz
 */
class RequestFailedException extends RuntimeException {

    private static final String SPACE = " ";

    RequestFailedException(HttpRequest request, HttpResponse response) {
        super(response.getStatusLine().getStatusCode() + SPACE
                + response.getStatusLine().getReasonPhrase() + SPACE
                + request.getRequestLine().getMethod() + SPACE
                + request.getRequestLine().getUri() + SPACE
                + failedResponseContent(response));
    }

    private static String failedResponseContent(HttpResponse response) {
        try {
            return inputStreamAsString(response.getEntity().getContent());
        } catch (Exception ignored) {
            return "";
        }
    }

}
